modelicares — ModelicaRes v0.8.0 Documentation
Description: Python module to set up, plot, and analyze Modelica simulations
Keywords: Modelica, Python, plot, results, simulation, experiment

### Navigation

- index
- modules |
- next |
- previous |
- ModelicaRes v0.8.0 Documentation »

# `modelicares`

Set up Modelica simulations and load, analyze, and plot the results.

This module provides direct access to the most important functions and classes from its submodules. These are:

- Basic supporting classes and functions: `base.add_arrows()`, `base.add_hlines()`, `base.add_vlines()`, `base.animate()`, `base.ArrowLine`, `base.closeall()`, `base.figure()`, `base.load_csv()`, `base.save()`, `base.saveall()`, `base.setup_subplots()`
- To manage simulation experiments: `exps.Experiment`, `exps.doe`, `exps.gen_experiments()`, `exps.ParamDict`, `exps.read_params()`, `exps.run_models()`, `exps.write_params()`, `exps.write_script()`
- To handle multiple files at once: `multi.multiload()`, `multi.multiplot()`
- For simulation results: `simres.SimRes`
- For linearization results: `linres.LinRes`
- To label numbers and quantities: `texunit.label_number()`, `texunit.label_quantity()`, `texunit.unit2tex()`

### Navigation

- index
- modules |
- next |
- previous |
- ModelicaRes v0.8.0 Documentation »